<?php

namespace FiloBlu\AdyenExchangeRate\Helper;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\Logger\Handler\Base;
use Magento\Store\Model\ScopeInterface;
use Monolog\Logger;

class CustomLogger
{
    const LOG_ENABLED = 'filoblu_adyenexchangerate/general/enable_log';

    /**
     * @var ScopeConfigInterface
     */
    private $scopeConfig;
    /**
     * @var Base
     */
    private $logger;

    public function __construct(
        ScopeConfigInterface $scopeConfig,
        Base                 $logger
    )
    {
        $this->scopeConfig = $scopeConfig;
        $this->logger = $logger;
    }

    /**
     * @param null|int|string $storeId
     * @return bool
     */
    public function logIsEnabled($storeId = null)
    {
        return $this->scopeConfig->isSetFlag(self::LOG_ENABLED, ScopeInterface::SCOPE_STORE, $storeId);
    }

    /**
     * @param array|string $data
     * @return array
     */
    protected function enrichData($data)
    {
        if (is_array($data)) {
            $data = json_encode($data);
        }
        return [
            'message' => $data,
            'datetime' => new \DateTime(),
            'channel' => 'filoblu_adyen_currency_exchange_rate',
            'level_name' => 'DEBUG',
            'level' => Logger::DEBUG,
            'context' => [],
            'extra' => []
        ];
    }

    /**
     * @param array|string $data
     * @param null|int|string $storeId
     */
    public function log($data, $storeId = null)
    {
        if ($this->logIsEnabled($storeId)) {
            $this->logger->handle($this->enrichData($data));
        }
    }
}
